summaryrefslogtreecommitdiffstats
path: root/kdat/FileInfoWidget.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdat/FileInfoWidget.h')
-rw-r--r--kdat/FileInfoWidget.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kdat/FileInfoWidget.h b/kdat/FileInfoWidget.h
index 9a0a32f..5e7f9e2 100644
--- a/kdat/FileInfoWidget.h
+++ b/kdat/FileInfoWidget.h
@@ -28,6 +28,7 @@ class TQLabel;
*/
class FileInfoWidget : public TQWidget {
Q_OBJECT
+ TQ_OBJECT
TQLabel* _fileName;
TQLabel* _ctime;
TQLabel* _mtime;
@@ -39,10 +40,10 @@ public:
/**
* Create a new file info widget.
*
* @param parent The parent widget.
* @param name The name of this widget.
*/
- FileInfoWidget( TQWidget* parent = 0, const char* name = 0 );
+ FileInfoWidget( TQWidget* tqparent = 0, const char* name = 0 );
/**
* Destroy the file info widget.
@@ -39,10 +40,10 @@ public:
* Create a new file info widget.
*
- * @param parent The parent widget.
+ * @param tqparent The tqparent widget.
* @param name The name of this widget.
*/